Gets the VPTS file coverage from supported sources per radar and date.
Usage
get_vpts_coverage(
source = c("baltrad", "uva", "ecog-04003", "rmi", "birdcast"),
...
)Gets the VPTS file coverage from supported sources per radar and date.
get_vpts_coverage(
source = c("baltrad", "uva", "ecog-04003", "rmi", "birdcast"),
...
)