Learn R Programming

getRad (version 0.2.4)

get_weather_radars: Get weather radar metadata

Description

Gets weather radar metadata from OPERA and/or NEXRAD.

Usage

get_weather_radars(source = c("opera", "nexrad"), use_cache = TRUE, ...)

Value

A sf or tibble with weather radar metadata. In all cases the column source is added to indicate the source of the data and radar to show the radar identifiers used in other functions like get_pvol() and get_vpts().

Arguments

source

Source of the metadata. "opera", "nexrad" or "all". If not provided, "opera" is used.

use_cache

Logical indicating whether to use the cache. Default is TRUE. If FALSE the cache is ignored and the file is fetched anew. This can also be useful if you want to force a refresh of the cache.

...

Additional arguments passed on to reading functions per source, currently not used.

Details

The source files for this function are:

Examples

Run this code
if (FALSE) { # interactive()
# Get radar metadata from OPERA
get_weather_radars(source = "opera")

# Get radar metadata from NEXRAD
get_weather_radars(source = "nexrad")
}

Run the code above in your browser using DataLab