A sf or tibble with weather radar metadata. In all cases the column source is
added to indicate the source of the data and radar to show the radar identifiers
used in other functions like get_pvol() and get_vpts().
Arguments
source
Source of the metadata. "opera", "nexrad" or "all".
If not provided, "opera" is used.
use_cache
Logical indicating whether to use the cache. Default is
TRUE. If FALSE the cache is ignored and the file is fetched anew.
This can also be useful if you want to force a refresh of the cache.
...
Additional arguments passed on to reading functions per source,
currently not used.
if (FALSE) { # interactive()# Get radar metadata from OPERAget_weather_radars(source = "opera")
# Get radar metadata from NEXRADget_weather_radars(source = "nexrad")
}